@@ -330,7 +330,7 @@
 #define	BCMXCP_ALARM_MAP_MAX 240 /* Max no of entries in BCM/XCP alarm map (adjusted upwards to nearest multi of 8 */
 
 typedef struct { /* Entry in BCM/XCP - UPS - NUT mapping table */
-	char *nut_entity;				/* The NUT variable name */
+	const char *nut_entity;				/* The NUT variable name */
 	unsigned char format;				/* The format of the data - float, long etc */
 	unsigned int meter_block_index;			/* The position of this meter in the UPS meter block */
 }	BCMXCP_METER_MAP_ENTRY_t;
@@ -340,7 +340,7 @@ BCMXCP_METER_MAP_ENTRY_t
 
 typedef	struct { /* Entry in BCM/XCP - UPS mapping table */
 	int alarm_block_index;			/* Index of this alarm in alarm block. -1 = not existing */
-	char *alarm_desc;			/* Description of this alarm */
+	const char *alarm_desc;			/* Description of this alarm */
 }	BCMXCP_ALARM_MAP_ENTRY_t;
 
 BCMXCP_ALARM_MAP_ENTRY_t
