@@ -5,6 +5,7 @@
 #ifndef BCMXCP_IO__
 #define BCMXCP_IO__
 
+#include "main.h"	/* for usbdrv_info_t */
 
 void send_read_command(unsigned char command);
 void send_write_command(unsigned char *command, int command_length);
@@ -16,4 +17,6 @@ void upsdrv_cleanup(void);
 void upsdrv_reconnect(void);
 void upsdrv_comm_good(void);
 
+extern upsdrv_info_t comm_upsdrv_info;
+
 #endif  /* BCMXCP_IO__ */
