@@ -6,7 +6,7 @@
 #define PW_MAX_BAUD 5
 
 #define SUBDRIVER_NAME	"RS-232 communication subdriver"
-#define SUBDRIVER_VERSION	"0.17"
+#define SUBDRIVER_VERSION	"0.18"
 
 /* communication driver description structure */
 upsdrv_info_t comm_upsdrv_info = {
@@ -47,8 +47,10 @@ static void send_command(unsigned char *command, int command_length)
 
 	while (retry++ < PW_MAX_TRY) {
 
-		if (retry == PW_MAX_TRY)
+		if (retry == PW_MAX_TRY) {
 			ser_send_char(upsfd, 0x1d);	/* last retry is preceded by a ESC.*/
+			usleep(250000);
+		}
 
 		sent = ser_send_buf(upsfd, sbuf, command_length);
 
@@ -82,7 +84,7 @@ int get_answer(unsigned char *data, unsigned char command)
 			res = ser_get_char(upsfd, my_buf, 1, 0);
 
 			if (res != 1) {
-				upsdebugx(1,"Receive error (PW_COMMAND_START_BYTE): %d!!!\n", res);
+				upsdebugx(1,"Receive error (PW_COMMAND_START_BYTE): %d, cmd=%x!!!\n", res, command);
 				return -1;
 			}
 
@@ -250,6 +252,7 @@ void upsdrv_comm_good()
 void pw_comm_setup(const char *port)
 {
 	unsigned char	command = PW_SET_REQ_ONLY_MODE;
+	unsigned char	id_command = PW_ID_BLOCK_REQ;
 	unsigned char	answer[256];
 	int		i = 0, baud, mybaud = 0, ret = -1;
 
@@ -274,6 +277,10 @@ void pw_comm_setup(const char *port)
 		send_write_command(AUT, 4);
 		usleep(500000);
 		ret = command_sequence(&command, 1, answer);
+		if (ret <= 0) {
+			usleep(500000);
+			ret = command_sequence(&id_command, 1, answer);
+		}
 
 		if (ret > 0) {
 			upslogx(LOG_INFO, "Connected to UPS on %s with baudrate %d", port, baud);
@@ -293,6 +300,10 @@ void pw_comm_setup(const char *port)
 		send_write_command(AUT, 4);
 		usleep(500000);
 		ret = command_sequence(&command, 1, answer);
+		if (ret <= 0) {
+			usleep(500000);
+			ret = command_sequence(&id_command, 1, answer);
+		}
 
 		if (ret > 0) {
 			upslogx(LOG_INFO, "Connected to UPS on %s with baudrate %d", port, pw_baud_rates[i].name);
