@@ -28,7 +28,7 @@
  *
  * -------------------------------------------------------------------------- */
 
-#include "config.h" /* for LIBUSB_HAS_DETACH_KRNL_DRV flag */
+#include "config.h" /* for HAVE_USB_DETACH_KERNEL_DRIVER_NP flag */
 #include "common.h" /* for xmalloc, upsdebugx prototypes */
 #include "usb-common.h"
 #include "libusb.h"
@@ -87,7 +87,7 @@ static inline int matches(USBDeviceMatcher_t *matcher, USBDevice_t *device) {
 static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDeviceMatcher_t *matcher,
 	int (*callback)(usb_dev_handle *udev, USBDevice_t *hd, unsigned char *rdbuf, int rdlen))
 {
-#if LIBUSB_HAS_DETACH_KRNL_DRV
+#ifdef HAVE_USB_DETACH_KERNEL_DRIVER_NP
 	int retries;
 #endif
 	int rdlen1, rdlen2; /* report descriptor length, method 1+2 */
@@ -96,8 +96,8 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 	struct usb_bus *bus;
 	usb_dev_handle *udev;
 	struct usb_interface_descriptor *iface;
-	
-	int ret, res; 
+
+	int ret, res;
 	unsigned char buf[20];
 	unsigned char *p;
 	char string[256];
@@ -121,7 +121,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 		for (dev = bus->devices; dev; dev = dev->next) {
 			upsdebugx(2, "Checking device (%04X/%04X) (%s/%s)", dev->descriptor.idVendor,
 				dev->descriptor.idProduct, bus->dirname, dev->filename);
-			
+
 			/* supported vendors are now checked by the
 			   supplied matcher */
 
@@ -147,7 +147,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 			curDevice->VendorID = dev->descriptor.idVendor;
 			curDevice->ProductID = dev->descriptor.idProduct;
 			curDevice->Bus = strdup(bus->dirname);
-			
+
 			if (dev->descriptor.iManufacturer) {
 				ret = usb_get_string_simple(udev, dev->descriptor.iManufacturer,
 					string, sizeof(string));
@@ -194,18 +194,18 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				}
 			}
 			upsdebugx(2, "Device matches");
-			
+
 			/* Now we have matched the device we wanted. Claim it. */
 
-#if LIBUSB_HAS_DETACH_KRNL_DRV
+#ifdef HAVE_USB_DETACH_KERNEL_DRIVER_NP
 			/* this method requires at least libusb 0.1.8:
 			 * it force device claiming by unbinding
 			 * attached driver... From libhid */
 			retries = 3;
 			while (usb_claim_interface(udev, 0) < 0) {
-				
+
 				upsdebugx(2, "failed to claim USB device: %s", usb_strerror());
-				
+
 				if (usb_detach_kernel_driver_np(udev, 0) < 0) {
 					upsdebugx(2, "failed to detach kernel driver from USB device: %s", usb_strerror());
 				} else {
@@ -223,10 +223,10 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				fatalx(EXIT_FAILURE, "Can't claim USB device [%04x:%04x]: %s", curDevice->VendorID, curDevice->ProductID, usb_strerror());
 			}
 #endif
-			
+
 			/* set default interface */
 			usb_set_altinterface(udev, 0);
-			
+
 			if (!callback) {
 				return 1;
 			}
@@ -235,7 +235,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				upsdebugx(2, "  Couldn't retrieve descriptors");
 				goto next_device;
 			}
-			
+
 			rdlen1 = -1;
 			rdlen2 = -1;
 
@@ -245,7 +245,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 			/* res = usb_get_descriptor(udev, USB_DT_HID, 0, buf, 0x9); */
 			res = usb_control_msg(udev, USB_ENDPOINT_IN+1, USB_REQ_GET_DESCRIPTOR,
 					      (USB_DT_HID << 8) + 0, 0, buf, 0x9, USB_TIMEOUT);
-			
+
 			if (res < 0) {
 				upsdebugx(2, "Unable to get HID descriptor (%s)", usb_strerror());
 			} else if (res < 9) {
@@ -255,7 +255,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				upsdebug_hex(3, "HID descriptor, method 1", buf, 9);
 
 				rdlen1 = buf[7] | (buf[8] << 8);
-			}			
+			}
 
 			if (rdlen1 < -1) {
 				upsdebugx(2, "Warning: HID descriptor, method 1 failed");
@@ -267,7 +267,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 
 			/* Note: on some broken UPS's (e.g. Tripp Lite Smart1000LCD),
 				only this second method gives the correct result */
-			
+
 			/* for now, we always assume configuration 0, interface 0,
 			   altsetting 0, as above. */
 			iface = &dev->config[0].interface[0].altsetting[0];
@@ -297,13 +297,13 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				goto next_device;
 			}
 			if (rdlen1 >= 0 && rdlen2 >= 0 && rdlen1 != rdlen2) {
-				upsdebugx(2, "Warning: two different HID descriptors retrieved (Reportlen = %u vs. %u)", rdlen1, rdlen2);
+				upsdebugx(2, "Warning: two different HID descriptors retrieved (Reportlen = %d vs. %d)", rdlen1, rdlen2);
 			}
 
 			upsdebugx(2, "HID descriptor length %d", rdlen);
 
 			if (rdlen > (int)sizeof(rdbuf)) {
-				upsdebugx(2, "HID descriptor too long %d (max %d)", rdlen, sizeof(rdbuf));
+				upsdebugx(2, "HID descriptor too long %d (max %d)", rdlen, (int)sizeof(rdbuf));
 				goto next_device;
 			}
 
@@ -329,7 +329,7 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 				goto next_device;
 			}
 
-			upsdebugx(2, "Report descriptor retrieved (Reportlen = %u)", rdlen);
+			upsdebugx(2, "Report descriptor retrieved (Reportlen = %d)", rdlen);
 			upsdebugx(2, "Found HID device");
 			fflush(stdout);
 
@@ -347,37 +347,93 @@ static int libusb_open(usb_dev_handle **udevp, USBDevice_t *curDevice, USBDevice
 	return -1;
 }
 
-/* return the report of ID=type in report 
+/*
+ * Error handler for usb_get/set_* functions. Return value > 0 success,
+ * 0 unknown or temporary failure (ignored), < 0 permanent failure (reconnect)
+ */
+static int libusb_strerror(const int ret, const char *desc)
+{
+	if (ret > 0) {
+		return ret;
+	}
+
+	switch(ret)
+	{
+	case -EBUSY:	/* Device or resource busy */
+	case -EPERM:	/* Operation not permitted */
+	case -ENODEV:	/* No such device */
+	case -EACCES:	/* Permission denied */
+	case -EIO:	/* I/O error */
+	case -ENXIO:	/* No such device or address */
+	case -ENOENT:	/* No such file or directory */
+	case -EPIPE:	/* Broken pipe */
+	case -ENOSYS:	/* Function not implemented */
+		upslogx(LOG_DEBUG, "%s: %s", desc, usb_strerror());
+		return ret;
+
+	case -ETIMEDOUT:	/* Connection timed out */
+		upsdebugx(2, "%s: Connection timed out", desc);
+		return 0;
+
+	case -EOVERFLOW:	/* Value too large for defined data type */
+	case -EPROTO:	/* Protocol error */
+		upsdebugx(2, "%s: %s", desc, usb_strerror());
+		return 0;
+
+	default:	/* Undetermined, log only */
+		upslogx(LOG_DEBUG, "%s: %s", desc, usb_strerror());
+		return 0;
+	}
+}
+
+/* return the report of ID=type in report
  * return -1 on failure, report length on success
  */
 
 static int libusb_get_report(usb_dev_handle *udev, int ReportId, unsigned char *raw_buf, int ReportSize )
 {
+	int	ret;
+
 	upsdebugx(4, "Entering libusb_get_report");
 
 	if (!udev) {
 		return 0;
 	}
 
-	return usb_control_msg(udev,
-		 USB_ENDPOINT_IN + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
-		 0x01, /* HID_REPORT_GET */
-		 ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
-		 0, raw_buf, ReportSize, USB_TIMEOUT);
-}
+	ret = usb_control_msg(udev,
+		USB_ENDPOINT_IN + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
+		0x01, /* HID_REPORT_GET */
+		ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
+		0, raw_buf, ReportSize, USB_TIMEOUT);
 
+	/* Ignore "protocol stall" (for unsupported request) on control endpoint */
+	if (ret == -EPIPE) {
+		return 0;
+	}
+
+	return libusb_strerror(ret, __func__);
+}
 
 static int libusb_set_report(usb_dev_handle *udev, int ReportId, unsigned char *raw_buf, int ReportSize )
 {
+	int	ret;
+
 	if (!udev) {
 		return 0;
 	}
 
-	return usb_control_msg(udev,
-		 USB_ENDPOINT_OUT + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
-		 0x09, /* HID_REPORT_SET = 0x09*/
-		 ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
-		 0, raw_buf, ReportSize, USB_TIMEOUT);
+	ret = usb_control_msg(udev,
+		USB_ENDPOINT_OUT + USB_TYPE_CLASS + USB_RECIP_INTERFACE,
+		0x09, /* HID_REPORT_SET = 0x09*/
+		ReportId+(0x03<<8), /* HID_REPORT_TYPE_FEATURE */
+		0, raw_buf, ReportSize, USB_TIMEOUT);
+
+	/* Ignore "protocol stall" (for unsupported request) on control endpoint */
+	if (ret == -EPIPE) {
+		return 0;
+	}
+
+	return libusb_strerror(ret, __func__);
 }
 
 static int libusb_get_string(usb_dev_handle *udev, int StringIdx, char *buf, size_t buflen)
@@ -389,13 +445,8 @@ static int libusb_get_string(usb_dev_handle *udev, int StringIdx, char *buf, siz
 	}
 
 	ret = usb_get_string_simple(udev, StringIdx, buf, buflen);
-	if (ret > 0) {
-		upsdebugx(5, "-> String: %s (len = %i/%i)", buf, ret, buflen);
-	} else {
-		upsdebugx(2, "- Unable to fetch string %d", StringIdx);
-	}
 
-	return ret;
+	return libusb_strerror(ret, __func__);
 }
 
 static int libusb_get_interrupt(usb_dev_handle *udev, unsigned char *buf, int bufsize, int timeout)
@@ -405,21 +456,16 @@ static int libusb_get_interrupt(usb_dev_handle *udev, unsigned char *buf, int bu
 	if (!udev) {
 		return -1;
 	}
-#ifdef SUN_LIBUSB
-/*
-	usleep(timeout * 1000);
- */
-	return 0;
-#else
+
 	/* FIXME: hardcoded interrupt EP => need to get EP descr for IF descr */
 	ret = usb_interrupt_read(udev, 0x81, (char *)buf, bufsize, timeout);
-	if (ret > 0) {
-		upsdebugx(6, " ok");
-	} else {
-		upsdebugx(6, " none (%i)", ret);
+
+	/* Clear stall condition */
+	if (ret == -EPIPE) {
+		ret = usb_clear_halt(udev, 0x81);
 	}
-	return ret;
-#endif
+
+	return libusb_strerror(ret, __func__);
 }
 
 static void libusb_close(usb_dev_handle *udev)
