@@ -26,7 +26,7 @@
 #include "usbhid-ups.h"
 #include "mge-hid.h"
 
-#define MGE_HID_VERSION		"MGE HID 1.19"
+#define MGE_HID_VERSION		"MGE HID 1.21"
 
 /* (prev. MGE Office Protection Systems, prev. MGE UPS SYSTEMS) */
 /* Eaton */
@@ -35,6 +35,9 @@
 /* Dell */
 #define DELL_VENDORID		0x047c
 
+/* Powerware */
+#define POWERWARE_VENDORID	0x0592
+
 #ifndef SHUT_MODE
 #include "usb-common.h"
 
@@ -47,6 +50,9 @@ static usb_device_id_t mge_usb_device_table[] = {
 	/* various models */
 	{ USB_DEVICE(DELL_VENDORID, 0xffff), NULL },
 
+	/* PW 9140 */
+	{ USB_DEVICE(POWERWARE_VENDORID, 0x0004), NULL },
+
 	/* Terminating entry */
 	{ -1, -1, NULL }
 };
@@ -492,7 +498,8 @@ static usage_lkp_t mge_usage_lkp[] = {
 	{ "HighHumidity",			0xffff0082 },
 	{ "LowTemperature",			0xffff0083 },
 	{ "HighTemperature",			0xffff0084 },
-	/* 0xffff0085-0xffff008f	=>	Reserved */
+	/* 0xffff0085-0xffff008f (minus 0xffff0086)	=>	Reserved */
+	{ "Efficiency",			0xffff0086 },
 	{ "Count",				0xffff0090 },
 	{ "Timer",				0xffff0091 },
 	{ "Interval",				0xffff0092 },
@@ -582,11 +589,17 @@ static models_name_t mge_model_names [] =
 	{ "PROTECTIONCENTER", "500", MGE_DEFAULT, "Protection Center 500" },
 	{ "PROTECTIONCENTER", "675", MGE_DEFAULT, "Protection Center 675" },
 
-	/* Protection Station */
+	/* Protection Station, supports Eco control */
 	{ "Protection Station", "500", MGE_PEGASUS, NULL },
 	{ "Protection Station", "650", MGE_PEGASUS, NULL },
 	{ "Protection Station", "800", MGE_PEGASUS, NULL },
 
+	/* Ellipse ECO, also supports Eco control */
+	{ "Ellipse ECO", "650", MGE_PEGASUS, NULL },
+	{ "Ellipse ECO", "800", MGE_PEGASUS, NULL },
+	{ "Ellipse ECO", "1200", MGE_PEGASUS, NULL },
+	{ "Ellipse ECO", "1600", MGE_PEGASUS, NULL },
+
 	/* Evolution models */
 	{ "Evolution", "500", MGE_DEFAULT, "Pulsar Evolution 500" },
 	{ "Evolution", "800", MGE_DEFAULT, "Pulsar Evolution 800" },
@@ -689,6 +702,7 @@ static hid_info_t mge_hid2nut[] =
 	{ "battery.charge.restart", ST_FLAG_RW | ST_FLAG_STRING, 3, "UPS.PowerSummary.RestartLevel", NULL, "%.0f", HU_FLAG_SEMI_STATIC, NULL },
 	{ "battery.capacity", 0, 0, "UPS.BatterySystem.Battery.DesignCapacity", NULL, "%s", HU_FLAG_STATIC, mge_battery_capacity },	/* conversion needed from As to Ah */
 	{ "battery.runtime", 0, 0, "UPS.PowerSummary.RunTimeToEmpty", NULL, "%.0f", 0, NULL },
+	{ "battery.runtime.low", ST_FLAG_RW | ST_FLAG_STRING, 10, "UPS.PowerSummary.RemainingTimeLimit", NULL, "%.0f", 0, NULL },
 	{ "battery.runtime.elapsed", 0, 0, "UPS.StatisticSystem.Input.[1].Statistic.[1].Time", NULL, "%.0f", HU_FLAG_QUICK_POLL, NULL },
 	{ "battery.temperature", 0, 0, "UPS.BatterySystem.Battery.Temperature", NULL, "%s", 0, kelvin_celsius_conversion },
 	{ "battery.type", 0, 0, "UPS.PowerSummary.iDeviceChemistry", NULL, "%s", HU_FLAG_STATIC, stringid_conversion },
@@ -700,6 +714,7 @@ static hid_info_t mge_hid2nut[] =
 	{ "battery.energysave", ST_FLAG_RW | ST_FLAG_STRING, 5, "UPS.PowerConverter.Input.[3].EnergySaving", NULL, "%s", HU_FLAG_SEMI_STATIC, yes_no_info },
 
 	/* UPS page */
+	{ "ups.efficiency", 0, 0, "UPS.PowerConverter.Output.Efficiency", NULL, "%.0f", 0, NULL },
 	{ "ups.firmware", 0, 0, "UPS.PowerSummary.iVersion", NULL, "%s", HU_FLAG_STATIC, stringid_conversion },
 	{ "ups.load", 0, 0, "UPS.PowerSummary.PercentLoad", NULL, "%.0f", 0, NULL },
 	{ "ups.load.high", ST_FLAG_RW | ST_FLAG_STRING, 5, "UPS.Flow.[4].ConfigPercentLoad", NULL, "%.0f", HU_FLAG_SEMI_STATIC, NULL },
@@ -767,7 +782,7 @@ static hid_info_t mge_hid2nut[] =
 	/* Battery DC voltage too high! */
 	{ "BOOL", 0, 0, "UPS.BatterySystem.Battery.PresentStatus.VoltageTooHigh", NULL, NULL, 0, battvolthi_info },
 	{ "BOOL", 0, 0, "UPS.BatterySystem.Charger.PresentStatus.VoltageTooLow", NULL, NULL, 0, battvoltlo_info },
-	{ "BOOL", 0, 0, "UPS.PowerConverter.Input.[1].PresentStatus.VoltageTooLow", NULL, NULL, 0, battvoltlo_info },
+	{ "BOOL", 0, 0, "UPS.PowerConverter.Input.[1].PresentStatus.VoltageTooLow", NULL, NULL, 0, mge_onbatt_info },
 	{ "BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.InternalFailure", NULL, NULL, 0, commfault_info },
 	{ "BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.OverTemperature", NULL, NULL, 0, overheat_info },
 	{ "BOOL", 0, 0, "UPS.PowerSummary.PresentStatus.ShutdownImminent", NULL, NULL, 0, shutdownimm_info },
