@@ -47,10 +47,10 @@ static int	offdelay = 60;	/* seconds */
 
 static char	powpan_answer[SMALLBUF];
 
-static const struct {
-	char	*var;
-	char	*get;
-	char	*set;
+static struct {
+	const char	*var;
+	const char	*get;
+	const char	*set;
 } vartab[] = {
 	{ "input.transfer.high", "P6\r", "C2:%03d\r" },
 	{ "input.transfer.low", "P7\r", "C3:%03d\r" },
@@ -58,9 +58,9 @@ static const struct {
 	{ NULL }
 };
 
-static const struct {
-	char	*cmd;
-	char	*command;
+static struct {
+	const char	*cmd;
+	const char	*command;
 } cmdtab[] = {
 	{ "test.battery.start.quick", "T\r" },
 	{ "test.battery.stop", "CT\r" },
@@ -208,7 +208,7 @@ static int powpan_setvar(const char *varname, const char *val)
 	return STAT_SET_UNKNOWN;
 }
 
-static void powpan_initinfo()
+static void powpan_initinfo(void)
 {
 	int	i;
 	char	*s;
@@ -410,7 +410,7 @@ static int powpan_status(status_t *status)
 	return 0;
 }
 
-static int powpan_updateinfo()
+static int powpan_updateinfo(void)
 {
 	status_t	status;
 
@@ -466,7 +466,7 @@ static int powpan_updateinfo()
 	return (status.flags[0] & 0x40) ? 1 : 0;
 }
 
-static int powpan_initups()
+static int powpan_initups(void)
 {
 	int	ret, i;
 
