@@ -17,11 +17,6 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-typedef struct {
-	char	*aclname;
-	void	*next;
-} acllist_t;
-
 typedef struct {
 	char	*cmd;
 	void	*next;
@@ -34,7 +29,6 @@ typedef struct {
 
 typedef struct {
 	char	*username;
-	acllist_t *firstacl;
 	char	*password;
 	instcmdlist_t *firstcmd;
 	actionlist_t  *firstaction;
